@@ -2,36 +2,80 @@
 # -*- coding: utf-8 -*-
 
 import asyncio
-from pathlib import Path
-from enum import Enum
 import sys
-from typing import List
+from enum import Enum
+from pathlib import Path
+from typing import List, Literal
 import typer
+from pydantic import BaseModel, Extra, Field, ValidationError, validator
+from rich.console import Console
 from rich import print
 
 # Detect if called from pypi installed package or via cloned github repo (development)
 try:
-    from centralcli import config, utils, cli, log, Response
+    from centralcli import Response, BatchRequest, caas, cleaner, cli, config, log, utils
 except (ImportError, ModuleNotFoundError) as e:
     pkg_dir = Path(__file__).absolute().parent
     if pkg_dir.name == "centralcli":
         sys.path.insert(0, str(pkg_dir.parent))
-        from centralcli import config, utils, cli, log, Response
+        from centralcli import Response, BatchRequest, caas, cleaner, cli, config, log, utils
     else:
         print(pkg_dir.parts)
         raise e
 
-from centralcli.constants import IdenMetaVars
-
+from centralcli.constants import GatewayRole, GenericDevIdens, IdenMetaVars, SendConfigDevIdens, SiteStates, state_abbrev_to_pretty
 
 iden_meta_vars = IdenMetaVars()
 tty = utils.tty
 app = typer.Typer()
 
+class GroupImport(BaseModel):
+    group: str
+    allowed_types: List[GenericDevIdens] = Field(["ap", "gw", "cx", "sw"], alias="types")
+    gw_role: GatewayRole = Field("branch", alias="gw-role")
+    aos10: bool = False
+    microbranch: bool = False
+    wlan_tg: bool = Field(False, alias="wlan-tg")
+    wired_tg: bool = Field(False, alias="wired-tg")
+    monitor_only_sw: bool = Field(False, alias="monitor-only-sw")
+    monitor_only_cx: bool = Field(False, alias="monitor-only-cx")
+    gw_config: Path = Field(None, alias="gw-config")
+    ap_config: Path = Field(None, alias="ap-config")
+    gw_vars: Path = Field(None, alias="gw-vars")
+    ap_vars: Path = Field(None, alias="ap-vars")
+
+    class Config:
+        use_enum_values = True
+
+class SiteImport(BaseModel):
+    site_name: str
+    address: str = None
+    city: str = None
+    state: str = None
+    country: str = Field(None, min_length=3)
+    zipcode: str = Field(None, min_length=5, alias="zip")
+    latitude: str = Field(None, min_length=5, alias="lat")
+    longitude: str = Field(None, min_length=5, alias="lon")
+
+    class Config:
+        extra = Extra.forbid
+        use_enum_values = True
+        allow_population_by_alias = True
+
+    @validator("state")
+    def short_to_long(cls, v: str) -> str:
+        try:
+            return SiteStates(state_abbrev_to_pretty.get(v.upper(), v.title())).value
+        except ValueError:
+            return SiteStates(v).value
+
+
+
 
 class BatchArgs(str, Enum):
     sites = "sites"
-    aps = "aps"
+    # aps = "aps"
+    groups = "groups"
 
 
 class BatchDelArgs(str, Enum):
@@ -181,12 +225,14 @@ def do_lldp_rename(fstr: str, **kwargs) -> Response:
         _warn = "\n\n[blink bright_red blink]WARNING[reset]"
         if need_lldp:
             _warn = f"{_warn} Format provided requires details about the upstream switch.\n"
-            _warn = f"{_warn} This automation will result in [cyan]{num_calls}[/] API calls. 3 per switch .\n"
+            _warn = f"{_warn} This automation will result in [cyan]{num_calls}[/] API calls. 3 per AP.\n"
             _warn = f"{_warn} 1 to gather details about the upstream switch\n"
         else:
             _warn = f"{_warn} This automation will result in [cyan]{num_calls}[/] API calls, 1 for each AP.\n"
-        _warn = f"{_warn}1 to get the aps curreant settings (all settings need to be provided during the update, only the name changes).\n"
-        _warn = f"{_warn}1 to rename the AP.\n"
+        _warn = f"{_warn} 1 to get the aps current settings (all settings need to be provided during the update, only the name changes).\n"
+        _warn = f"{_warn} 1 to Update the settings / rename the AP.\n"
+        _warn = f"{_warn}\n Current daily quota: [bright_green]{resp.rl.remain_day}[/] calls remaining\n"
+
 
         print(_warn)
         if resp.rl.remain_day < num_calls:
@@ -313,7 +359,7 @@ def do_lldp_rename(fstr: str, **kwargs) -> Response:
         typer.echo("\n".join(
                 [
                     *name_list[0:3],
-                    "...",
+                    "  ...",
                     *name_list[-3:]
                 ]
             )
@@ -322,6 +368,220 @@ def do_lldp_rename(fstr: str, **kwargs) -> Response:
     if typer.confirm("Proceed with AP Rename?", abort=True):
         return cli.central.batch_request(req_list)
 
+def batch_add_sites(import_file: Path, yes: bool = False) -> Response:
+    central = cli.central
+    name_aliases = ["site-name", "site", "name"]
+    _site_aliases = {
+        "site-name": "site_name",
+        "site": "site_name",
+        "name": "site_name",
+        "latitude": "lat",
+        "longitude": "lon",
+        "zipcode": "zip",
+    }
+
+    def convert_site_key(_data: dict) -> dict:
+        _data = {
+            **_data.get("site_address", {}),
+            **_data.get("geolocation", {}),
+            **{k: v for k, v in _data.items() if k not in ["site_address", "geolocation"]}
+        }
+        _data = {_site_aliases.get(k, k): v for k, v in _data.items()}
+        return _data
+
+    data = config.get_file_data(import_file)
+    if "sites" in data:
+        data = data["sites"]
+
+    resp = None
+    verified_sites: List[SiteImport] = []
+    # TODO test with csv ... NOT YET TESTED
+    if import_file.suffix in [".csv", ".tsv", ".dbf", ".xls", ".xlsx"]:
+        verified_sites = [SiteImport(**convert_site_key(i)) for i in data.dict]
+    else:
+        # We allow a list of flat dicts or a list of dicts where loc info is under
+        # "site_address" or "geo_location"
+        # can be keyed on name or flat.
+        for i in data:
+            if isinstance(i, str) and isinstance(data[i], dict):
+                out_dict = convert_site_key(
+                    {"site_name": i, **data[i]}
+                )
+            else:
+                out_dict = convert_site_key(i)
+
+            verified_sites += [SiteImport(**out_dict)]
+
+    site_names = [
+        f"  [cyan]{s.site_name}[/]" for s in verified_sites
+    ]
+    if len(site_names) > 7:
+        site_names = [*site_names[0:3], "  ...", *site_names[-3:]]
+
+    print("[bright_green]The Following Sites will be created:[/]")
+    _ = [print(s) for s in site_names]
+
+    if yes or typer.confirm("Proceed?", abort=True):
+        reqs = [
+            BatchRequest(central.create_site, **site.dict())
+            for site in verified_sites
+        ]
+        resp = central.batch_request(reqs)
+        if all([r.ok for r in resp]):
+            resp[-1].output = [r.output for r in resp]
+            resp = resp[-1]
+            cache_res = asyncio.run(cli.cache.update_site_db(data=resp.output))
+            if len(cache_res) != len(data):
+                log.warning(
+                    "Attempted to add entries to Site Cache after batch import.  Cache Response "
+                    f"{len(cache_res)} but we added {len(data)} sites.",
+                    show=True
+                )
+        return resp
+
+# TODO REMOVE NOT USED (keeping for now in case I change my mind)
+# class BatchRequest(BaseModel):
+#     func: Callable
+#     args: Tuple = ()
+#     kwargs: Dict[str, Any] = {}
+
+class PreConfig(BaseModel):
+    name: str
+    config: str
+    request: BatchRequest
+
+    class Config:
+        arbitrary_types_allowed = True
+
+
+def _build_pre_config(node: str, dev_type: SendConfigDevIdens, cfg_file: Path, var_file: Path = None) -> PreConfig:
+    """Build Configuration from raw config or jinja2 template/variable file.
+
+    Args:
+        node (str): The name of the central node (group name or device MAC for gw)
+        dev_type (str): Type of device being pre-provisioned.  One of 'gw' or 'ap'.
+        cfg_file (Path): Path of the config file.
+        var_file (Path, optional): Path of the variable file. Defaults to None.
+
+    Raises:
+        typer.Exit: If config is j2 template but no variable file is found.
+        typer.Exit: If result of config generation yields no commands
+
+    Returns:
+        PreConfig: PreConfig object
+    """
+    if not cfg_file.exists():
+        print(f":warning: [cyan]{node}[/] {cfg_file} not found.  Unable to generate config.")
+        raise typer.Exit(1)
+
+    br = cli.central.BatchRequest
+    caasapi = caas.CaasAPI(central=cli.central)
+    config_out = utils.generate_template(cfg_file, var_file=var_file)
+    commands = utils.validate_config(config_out)
+
+    if dev_type == "gw":
+        return PreConfig(name=node, config=config_out, request=br(caasapi.send_commands, node, cli_cmds=commands))
+    elif dev_type == "ap":
+        return PreConfig(name=node, config=config_out, request=br(cli.central.replace_ap_config, node, clis=commands))
+
+
+# TODO update cache after succesful group add
+def batch_add_groups(import_file: Path, yes: bool = False) -> List[Response]:
+    console = Console(emoji=False)
+    br = cli.central.BatchRequest
+    data = config.get_file_data(import_file)
+    # TODO handle csv
+    if isinstance(data, dict) and "groups" in data:
+        data = data["groups"]
+    reqs, gw_reqs, ap_reqs = [], [], []
+    pre_cfgs = []
+    _pre_config_msg = ""
+    cache_data = []
+    for group in data:
+        if "allowed-types" in data[group]:
+            data[group]["allowed_types"] = data[group]["allowed-types"]
+            del data[group]["allowed-types"]
+
+        try:
+            g = GroupImport(**{"group": group, **data[group]})
+        except ValidationError as e:
+            print(e)
+            raise typer.Exit(1)
+        reqs += [
+            br(
+                cli.central.create_group,
+                g.group,
+                allowed_types=g.allowed_types,
+                wired_tg=g.wired_tg,
+                wlan_tg=g.wlan_tg,
+                aos10=g.aos10,
+                microbranch=g.microbranch,
+                gw_role=g.gw_role,
+                monitor_only_sw=g.monitor_only_sw,
+                monitor_only_cx=g.monitor_only_cx,
+            )
+        ]
+        cache_data += [
+            {"name": g.group, "template group": {"Wired": g.wired_tg, "Wireless": g.wlan_tg}}
+        ]
+        for dev_type, cfg_file, var_file in zip(["gw", "ap"], [g.gw_config, g.ap_config], [g.gw_vars, g.ap_vars]):
+            if cfg_file is not None:
+                pc = _build_pre_config(g.group, dev_type=dev_type, cfg_file=cfg_file, var_file=var_file)
+                pre_cfgs += [pc]
+                _pre_config_msg += (
+                    f"  [bright_green]{len(pre_cfgs)}[/]. [cyan]{g.group}[/] {'gateways' if dev_type == 'gw' else 'AP'} "
+                    f"group level will be configured based on [cyan]{cfg_file.name}[/]\n"
+                )
+                if dev_type == "gw":
+                    gw_reqs += [pc.request]
+                else:
+                    ap_reqs += [pc.request]
+
+    print(f"[bright_green]The following groups will be created:[/]")
+    _ = [print(f"  [cyan]{g}[/]") for g in data]
+
+    _pre_config_msg = (
+        "\n[bright_green]Group level configurations will be sent:[/]\n"
+        f"{_pre_config_msg}"
+        f"\n[italic dark_olive_green2]{len(reqs) + len(gw_reqs) + len(ap_reqs)} API calls will be performed.[/]\n"
+    )
+    print(_pre_config_msg)
+    for idx in range(len(pre_cfgs) + 1):
+        if idx > 0:
+            print(_pre_config_msg)
+        print(f"Select [bright_green]#[/] to display config to be sent or [bright_green]go[/] to continue.")
+        ch = utils.ask(
+            ">",
+            console=console,
+            choices=[*[str(idx) for idx in range(1, len(pre_cfgs) + 1)], "abort", "go"],
+        )
+        if ch.lower() == "go":
+            yes = True
+            break
+        else:
+            pc: PreConfig = pre_cfgs[int(ch) - 1]
+            console.rule(f"Config to be sent to {pc.name}")
+            with console.pager():
+                console.print(pc.config)
+            console.rule(f" End {pc.name} config ")
+
+    if reqs and yes or typer.confirm("Proceed?", abort=True):
+        resp = cli.central.batch_request(reqs)
+        if all(r.ok for r in resp):
+            cache_resp = asyncio.run(cli.cache.update_group_db(cache_data))
+            log.debug(f"batch add group cache resp: {cache_resp}")
+        cli.display_results(resp)
+        if gw_reqs:
+            print("\n[bright_green]Results from Group level gateway config push (CLI commands)[/]")
+            print("\n  [italic]This can take some time.[/]")
+            resp = cli.central.batch_request(gw_reqs)
+            cli.display_results(resp, cleaner=cleaner.parse_caas_response)
+        if ap_reqs:
+            print("\n[bright_green]Results from Group level AP config push (Replaces entire group level)[/]\n")
+            resp = cli.central.batch_request(ap_reqs)
+            cli.display_results(resp,  tablefmt="action")
+
+
 
 @app.command(short_help="Perform Batch Add from file")
 def add(
@@ -343,126 +603,11 @@ def add(
 ) -> None:
     """Perform batch Add operations using import data from file."""
     yes = yes_ if yes_ else yes
-    central = cli.central
-    data = config.get_file_data(import_file)
-    address_fields = [
-        "address",
-        "city",
-        "state",
-        "zipcode",
-        "country"
-    ]
-    def _field_error(field: str = None):
-        valid_field_list = [
-            [
-            "site_name",
-            *address_fields
-            ],
-            [
-            "site_name",
-            "longitude",
-            "latitude"
-            ]
-        ]
-        valid_fields = ["\n".join(v) for v in valid_field_list]
-        if field:
-            print(f"[red]Error:[/red] Missing Required field {field}")
-
-        print(
-            f"\n[bright_green]Valid Fields[/bright_green]:\n--\n{valid_fields[0]}\n--OR--\n{valid_fields[1]}"
-        )
-        raise typer.Exit(1)
-
-    resp = None
     if what == "sites":
-        if import_file.suffix in [".csv", ".tsv", ".dbf", ".xls", ".xlsx"]:
-            # TODO Exception handler
-            if "address" in str(data.headers) and len(data.headers) > 3:  # address info
-                data = [
-                    {
-                        "site_name": i.get("site_name", i.get("site", i.get("name"))),
-                        "site_address": {k: v for k, v in i.items() if k not in ["site", "site_name"]}
-                    }
-                    for i in data.dict
-                ]
-            else:  # geoloc
-                data = [
-                    {
-                        "site_name": i.get("site_name", i.get("site", i.get("name"))),
-                        "geolocation": {k: v for k, v in i.items() if k not in ["site", "site_name"]}
-                    }
-                    for i in data.dict
-                ]
-        else:
-            # We allow a list of flat dicts or a list of dicts where loc info is under
-            # "site_address" or "geo_location"
-            for i in data:
-                i["site_name"] = i.get("site_name", i.get("name", i.get("site")))
-                for k in ["site", "name"]:
-                    if k in i:
-                        del i[k]
-                # TODO no validation on first 2.
-                # FIXME this function needs cleanup... pydantic? for validation
-                if "site_address" in i:
-                    i["site_address"] = {k: str(v) for k, v in i["site_address"].items()}
-                elif "geolocation" in i:
-                    i["geolocation"] = {k: str(v) for k, v in i["geolocation"].items()}
-                elif "longitude" in i:
-                    if "latitude" not in i:
-                        _field_error("latitude")
-                    i["geolocation"] = {k: str(v) for k, v in i.items() if k != "site_name"}
-                else:
-                    i["site_address"] = {k: str(v) for k, v in i.items() if k != "site_name"}
-                    if not [k for k in list(i.keys()) if k in address_fields]:
-                        print(f"[red]Error:[/red] Error parsing site [cyan]{i['site_name']}")
-                        print("Error provided address fields:")
-                        utils.json_print(i)
-                        _field_error()
-
-                for k in ["site", "name", "longitude", "latitude", *address_fields]:
-                    if k in i:
-                        del i[k]
-
-                if len(i) != 2:
-                    print(f"[red]Error:[/red] Invalid fields found in data for site {i['site_name']}")
-                    utils.json_print(i)
-                    invalid = ", ".join(f for f in i if f not in ["site_name", "site_address", "geolocation"])
-                    print(f"[italic]{invalid}[/italic] is an invalid field.")
-                    _field_error()
-
-        # Verify no name errors input can use site_name, site, or name
-        site_names = [
-            d.get("site_name", "ERROR") for d in data
-        ]
-        if "ERROR" in site_names:
-            print(f"[red]Error:[/red] Error parsing [cyan]'site_name'")
-            utils.json_print(data[site_names.index("ERROR")])
-            _field_error()
-
-        if len(site_names) > 7:
-            site_names = [*site_names[0:3], "...", *site_names[-3:]]
-        _msg = [
-            typer.style("Batch Add Sites:", fg="cyan"),
-            typer.style(
-                "\n".join([typer.style(f'  {n}', fg="bright_green" if n != "..." else "reset") for n in site_names])
-            ),
-            typer.style("Proceed with Site Additions?", fg="cyan")
-        ]
-        _msg = "\n".join(_msg)
-        if yes or typer.confirm(_msg, abort=True):
-            resp = central.request(central.create_site, site_list=data)
-            if all([r.ok for r in resp]):
-                resp[-1].output = [r.output for r in resp]
-                resp = resp[-1]
-                cache_res = asyncio.run(cli.cache.update_site_db(data=resp.output))
-                if len(cache_res) != len(data):
-                    log.warning(
-                        "Attempted to add entries to Site Cache after batch import.  Cache Response "
-                        f"{len(cache_res)} but we added {len(data)} sites.",
-                        show=True
-                    )
-
-    cli.display_results(resp)
+        resp = batch_add_sites(import_file, yes)
+        cli.display_results(resp)
+    elif what == "groups":
+        batch_add_groups(import_file, yes)
 
 
 @app.command()
@@ -542,7 +687,7 @@ def delete(
     cli.display_results(resp)
 
 
-@app.command()
+@app.command(help="Batch rename APs based on import file or site/LLDP info.")
 def rename(
     what: BatchArgs = typer.Argument(...,),
     import_file: Path = typer.Argument(None, metavar="['lldp'|IMPORT FILE PATH]"),  # TODO completion
