@@ -62,7 +62,7 @@ def rogues(
     do_csv: bool = typer.Option(False, "--csv", is_flag=True, help="Output in CSV"),
     do_table: bool = typer.Option(False, "--table", help="Output in table format",),
     outfile: Path = typer.Option(None, "--out", help="Output to file (and terminal)", writable=True),
-    no_pager: bool = typer.Option(False, "--no-pager", help="Disable Paged Output"),
+    pager: bool = typer.Option(False, "--pager", help="Enable Paged Output"),
     update_cache: bool = typer.Option(False, "-U", hidden=True),  # Force Update of cli.cache for testing
     default: bool = typer.Option(False, "-d", is_flag=True, help="Use default central account", show_default=False,),
     debug: bool = typer.Option(False, "--debug", envvar="ARUBACLI_DEBUG", help="Enable Additional Debug Logging",),
@@ -116,7 +116,7 @@ def rogues(
         resp,
         tablefmt=tablefmt,
         title="Rogues",
-        pager=not no_pager,
+        pager=pager,
         outfile=outfile,
         sort_by=sort_by if not sort_by else sort_by.replace("_", " "),
         reverse=reverse,
@@ -147,7 +147,7 @@ def interfering(
     do_csv: bool = typer.Option(False, "--csv", is_flag=True, help="Output in CSV"),
     do_table: bool = typer.Option(False, "--table", help="Output in table format",),
     outfile: Path = typer.Option(None, "--out", help="Output to file (and terminal)", writable=True),
-    no_pager: bool = typer.Option(False, "--no-pager", help="Disable Paged Output"),
+    pager: bool = typer.Option(False, "--pager", help="Enable Paged Output"),
     update_cache: bool = typer.Option(False, "-U", hidden=True),  # Force Update of cli.cache for testing
     default: bool = typer.Option(False, "-d", is_flag=True, help="Use default central account", show_default=False,),
     debug: bool = typer.Option(False, "--debug", envvar="ARUBACLI_DEBUG", help="Enable Additional Debug Logging",),
@@ -201,7 +201,7 @@ def interfering(
         resp,
         tablefmt=tablefmt,
         title="Interfering APs",
-        pager=not no_pager,
+        pager=pager,
         outfile=outfile,
         sort_by=sort_by if not sort_by else sort_by.replace("_", " "),
         reverse=reverse,
@@ -232,7 +232,7 @@ def neighbor(
     do_csv: bool = typer.Option(False, "--csv", is_flag=True, help="Output in CSV"),
     do_table: bool = typer.Option(False, "--table", help="Output in table format",),
     outfile: Path = typer.Option(None, "--out", help="Output to file (and terminal)", writable=True),
-    no_pager: bool = typer.Option(False, "--no-pager", help="Disable Paged Output"),
+    pager: bool = typer.Option(False, "--pager", help="Enable Paged Output"),
     update_cache: bool = typer.Option(False, "-U", hidden=True),  # Force Update of cli.cache for testing
     default: bool = typer.Option(False, "-d", is_flag=True, help="Use default central account", show_default=False,),
     debug: bool = typer.Option(False, "--debug", envvar="ARUBACLI_DEBUG", help="Enable Additional Debug Logging",),
@@ -286,7 +286,7 @@ def neighbor(
         resp,
         tablefmt=tablefmt,
         title="Suspected Rogues",
-        pager=not no_pager,
+        pager=pager,
         outfile=outfile,
         sort_by=sort_by if not sort_by else sort_by.replace("_", " "),
         reverse=reverse,
@@ -317,7 +317,7 @@ def suspect(
     do_csv: bool = typer.Option(False, "--csv", is_flag=True, help="Output in CSV"),
     do_table: bool = typer.Option(False, "--table", help="Output in table format",),
     outfile: Path = typer.Option(None, "--out", help="Output to file (and terminal)", writable=True),
-    no_pager: bool = typer.Option(False, "--no-pager", help="Disable Paged Output"),
+    pager: bool = typer.Option(False, help="Enable Paged Output"),
     update_cache: bool = typer.Option(False, "-U", hidden=True),  # Force Update of cli.cache for testing
     default: bool = typer.Option(False, "-d", is_flag=True, help="Use default central account", show_default=False,),
     debug: bool = typer.Option(False, "--debug", envvar="ARUBACLI_DEBUG", help="Enable Additional Debug Logging",),
@@ -371,7 +371,7 @@ def suspect(
         resp,
         tablefmt=tablefmt,
         title="Suspected Rogues",
-        pager=not no_pager,
+        pager=pager,
         outfile=outfile,
         sort_by=sort_by if not sort_by else sort_by.replace("_", " "),
         reverse=reverse,
